/****************************************************************************
** Meta object code from reading C++ file 'qtsensorgesturesensorhandler.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.13)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../git/src/plugins/sensorgestures/qtsensors/qtsensorgesturesensorhandler.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtsensorgesturesensorhandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.13. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtSensorGestureSensorHandler_t {
    QByteArrayData data[27];
    char stringdata0[423];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtSensorGestureSensorHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtSensorGestureSensorHandler_t qt_meta_stringdata_QtSensorGestureSensorHandler = {
    {
QT_MOC_LITERAL(0, 0, 28), // "QtSensorGestureSensorHandler"
QT_MOC_LITERAL(1, 29, 19), // "accelReadingChanged"
QT_MOC_LITERAL(2, 49, 0), // ""
QT_MOC_LITERAL(3, 50, 22), // "QAccelerometerReading*"
QT_MOC_LITERAL(4, 73, 7), // "reading"
QT_MOC_LITERAL(5, 81, 25), // "orientationReadingChanged"
QT_MOC_LITERAL(6, 107, 20), // "QOrientationReading*"
QT_MOC_LITERAL(7, 128, 23), // "proximityReadingChanged"
QT_MOC_LITERAL(8, 152, 18), // "QProximityReading*"
QT_MOC_LITERAL(9, 171, 25), // "irProximityReadingChanged"
QT_MOC_LITERAL(10, 197, 20), // "QIRProximityReading*"
QT_MOC_LITERAL(11, 218, 18), // "dTabReadingChanged"
QT_MOC_LITERAL(12, 237, 12), // "QTapReading*"
QT_MOC_LITERAL(13, 250, 12), // "accelChanged"
QT_MOC_LITERAL(14, 263, 18), // "orientationChanged"
QT_MOC_LITERAL(15, 282, 16), // "proximityChanged"
QT_MOC_LITERAL(16, 299, 18), // "irProximityChanged"
QT_MOC_LITERAL(17, 318, 9), // "doubletap"
QT_MOC_LITERAL(18, 328, 11), // "startSensor"
QT_MOC_LITERAL(19, 340, 20), // "SensorGestureSensors"
QT_MOC_LITERAL(20, 361, 6), // "sensor"
QT_MOC_LITERAL(21, 368, 10), // "stopSensor"
QT_MOC_LITERAL(22, 379, 5), // "Accel"
QT_MOC_LITERAL(23, 385, 11), // "Orientation"
QT_MOC_LITERAL(24, 397, 9), // "Proximity"
QT_MOC_LITERAL(25, 407, 11), // "IrProximity"
QT_MOC_LITERAL(26, 419, 3) // "Tap"

    },
    "QtSensorGestureSensorHandler\0"
    "accelReadingChanged\0\0QAccelerometerReading*\0"
    "reading\0orientationReadingChanged\0"
    "QOrientationReading*\0proximityReadingChanged\0"
    "QProximityReading*\0irProximityReadingChanged\0"
    "QIRProximityReading*\0dTabReadingChanged\0"
    "QTapReading*\0accelChanged\0orientationChanged\0"
    "proximityChanged\0irProximityChanged\0"
    "doubletap\0startSensor\0SensorGestureSensors\0"
    "sensor\0stopSensor\0Accel\0Orientation\0"
    "Proximity\0IrProximity\0Tap"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtSensorGestureSensorHandler[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       1,  100, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,
       5,    1,   77,    2, 0x06 /* Public */,
       7,    1,   80,    2, 0x06 /* Public */,
       9,    1,   83,    2, 0x06 /* Public */,
      11,    1,   86,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    0,   89,    2, 0x0a /* Public */,
      14,    0,   90,    2, 0x0a /* Public */,
      15,    0,   91,    2, 0x0a /* Public */,
      16,    0,   92,    2, 0x0a /* Public */,
      17,    0,   93,    2, 0x0a /* Public */,
      18,    1,   94,    2, 0x0a /* Public */,
      21,    1,   97,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    4,
    QMetaType::Void, 0x80000000 | 8,    4,
    QMetaType::Void, 0x80000000 | 10,    4,
    QMetaType::Void, 0x80000000 | 12,    4,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool, 0x80000000 | 19,   20,
    QMetaType::Void, 0x80000000 | 19,   20,

 // enums: name, alias, flags, count, data
      19,   19, 0x0,    5,  105,

 // enum data: key, value
      22, uint(QtSensorGestureSensorHandler::Accel),
      23, uint(QtSensorGestureSensorHandler::Orientation),
      24, uint(QtSensorGestureSensorHandler::Proximity),
      25, uint(QtSensorGestureSensorHandler::IrProximity),
      26, uint(QtSensorGestureSensorHandler::Tap),

       0        // eod
};

void QtSensorGestureSensorHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QtSensorGestureSensorHandler *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->accelReadingChanged((*reinterpret_cast< QAccelerometerReading*(*)>(_a[1]))); break;
        case 1: _t->orientationReadingChanged((*reinterpret_cast< QOrientationReading*(*)>(_a[1]))); break;
        case 2: _t->proximityReadingChanged((*reinterpret_cast< QProximityReading*(*)>(_a[1]))); break;
        case 3: _t->irProximityReadingChanged((*reinterpret_cast< QIRProximityReading*(*)>(_a[1]))); break;
        case 4: _t->dTabReadingChanged((*reinterpret_cast< QTapReading*(*)>(_a[1]))); break;
        case 5: _t->accelChanged(); break;
        case 6: _t->orientationChanged(); break;
        case 7: _t->proximityChanged(); break;
        case 8: _t->irProximityChanged(); break;
        case 9: _t->doubletap(); break;
        case 10: { bool _r = _t->startSensor((*reinterpret_cast< SensorGestureSensors(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->stopSensor((*reinterpret_cast< SensorGestureSensors(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAccelerometerReading* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QOrientationReading* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QProximityReading* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QIRProximityReading* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QTapReading* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QtSensorGestureSensorHandler::*)(QAccelerometerReading * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QtSensorGestureSensorHandler::accelReadingChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QtSensorGestureSensorHandler::*)(QOrientationReading * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QtSensorGestureSensorHandler::orientationReadingChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QtSensorGestureSensorHandler::*)(QProximityReading * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QtSensorGestureSensorHandler::proximityReadingChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QtSensorGestureSensorHandler::*)(QIRProximityReading * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QtSensorGestureSensorHandler::irProximityReadingChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QtSensorGestureSensorHandler::*)(QTapReading * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QtSensorGestureSensorHandler::dTabReadingChanged)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QtSensorGestureSensorHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QtSensorGestureSensorHandler.data,
    qt_meta_data_QtSensorGestureSensorHandler,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtSensorGestureSensorHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtSensorGestureSensorHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtSensorGestureSensorHandler.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QtSensorGestureSensorHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void QtSensorGestureSensorHandler::accelReadingChanged(QAccelerometerReading * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QtSensorGestureSensorHandler::orientationReadingChanged(QOrientationReading * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QtSensorGestureSensorHandler::proximityReadingChanged(QProximityReading * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QtSensorGestureSensorHandler::irProximityReadingChanged(QIRProximityReading * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QtSensorGestureSensorHandler::dTabReadingChanged(QTapReading * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
