/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -N -p sensorproxy_interface.h: /scratch/jenkins-BUILDS-eSDK-2025.2_stable-pipeline-build-127_zcu102_sdt_full/build/tmp/work/zynqmp_zcu102_sdt-amd-linux/qtsensors/5.15.13+git/git/src/plugins/sensors/iio-sensor-proxy/net.hadess.SensorProxy.xml
 *
 * qdbusxml2cpp is Copyright (C) 2022 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef SENSORPROXY_INTERFACE_H
#define SENSORPROXY_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface net.hadess.SensorProxy
 */
class NetHadessSensorProxyInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "net.hadess.SensorProxy"; }

public:
    NetHadessSensorProxyInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~NetHadessSensorProxyInterface();

    Q_PROPERTY(QString AccelerometerOrientation READ accelerometerOrientation)
    inline QString accelerometerOrientation() const
    { return qvariant_cast< QString >(property("AccelerometerOrientation")); }

    Q_PROPERTY(bool HasAccelerometer READ hasAccelerometer)
    inline bool hasAccelerometer() const
    { return qvariant_cast< bool >(property("HasAccelerometer")); }

    Q_PROPERTY(bool HasAmbientLight READ hasAmbientLight)
    inline bool hasAmbientLight() const
    { return qvariant_cast< bool >(property("HasAmbientLight")); }

    Q_PROPERTY(double LightLevel READ lightLevel)
    inline double lightLevel() const
    { return qvariant_cast< double >(property("LightLevel")); }

    Q_PROPERTY(QString LightLevelUnit READ lightLevelUnit)
    inline QString lightLevelUnit() const
    { return qvariant_cast< QString >(property("LightLevelUnit")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> ClaimAccelerometer()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ClaimAccelerometer"), argumentList);
    }

    inline QDBusPendingReply<> ClaimLight()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ClaimLight"), argumentList);
    }

    inline QDBusPendingReply<> ReleaseAccelerometer()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ReleaseAccelerometer"), argumentList);
    }

    inline QDBusPendingReply<> ReleaseLight()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ReleaseLight"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

#endif
