/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -i properties_interface.h -p :properties_interface.cpp /scratch/jenkins-BUILDS-eSDK-2025.2_stable-pipeline-build-127_zcu102_sdt_full/build/tmp/work/zynqmp_zcu102_sdt-amd-linux/qtsensors/5.15.13+git/git/src/plugins/sensors/iio-sensor-proxy/org.freedesktop.DBus.Properties.xml
 *
 * qdbusxml2cpp is Copyright (C) 2022 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "properties_interface.h"
/*
 * Implementation of interface class OrgFreedesktopDBusPropertiesInterface
 */

OrgFreedesktopDBusPropertiesInterface::OrgFreedesktopDBusPropertiesInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopDBusPropertiesInterface::~OrgFreedesktopDBusPropertiesInterface()
{
}

